<?php
/**
 * Plugin Name: DMG Atex
 * Plugin URI: https://github.com/ANMedia/dmg-atex-wp-plugin
 * Description: Tools to modify the blocks output for Atex
 * Version: 1.0.1
 */

namespace DMG;

/**
 * Class Atex
 *
 * Actions for serving content to Atex
 */
class Atex {

	/**
	 * Query param
	 *
	 * @var string
	 */
	const QUERY_PARAM = 'dmg_atex_content';

	/**
	 * init
	 *
	 * @return void
	 */
	public static function init(): void {
		add_action( 'rest_api_init', array( __CLASS__, 'check_request' ) );
	}

	/**
	 * Check if this API request is an Atex request
	 *
	 * @return void
	 */
	public static function check_request(): void {

		// Check query param
		// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		if ( empty( $_GET[ self::QUERY_PARAM ] )
		     || false === filter_var( $_GET[ self::QUERY_PARAM ], FILTER_VALIDATE_BOOLEAN )
		) {
			return;
		}

		// Provide a filter to modify block output
		$blocks = apply_filters( 'dmg_atex_content_blocks', array() );

		// Loop through and remove/re-add blocks using new render_callbacks
		foreach ( $blocks as $block => $callback ) {
			unregister_block_type( $block );
			register_block_type(
				$block,
				array(
					'render_callback' => $callback
				)
			);
		}

		// Remove extra whitespace
		add_filter( 'rest_prepare_post', array( __CLASS__, 'trim_whitespace' ), 99 );
		add_filter( 'rest_prepare_post', array( __CLASS__, 'remove_inline_styles' ), 99 );
	}

	/**
	 * Remove extra whitespace resulting from blanked out shortcodes
	 *
	 * @param \WP_REST_Response $response The response object
	 *
	 * @return \WP_REST_Response The filtered response object
	 */
	public static function trim_whitespace( \WP_REST_Response $response ): \WP_REST_Response {
		if ( isset( $response->data['content']['rendered'] ) ) {
			$response->data['content']['rendered'] = trim( preg_replace( "/\n\n+/", "\n\n", $response->data['content']['rendered'] ) );
		}

		return $response;
	}

	/**
	 * Remove inline CSS <style> tags
	 *
	 * @param \WP_REST_Response $response The response object
	 *
	 * @return \WP_REST_Response The filtered response object
	 */
	public static function remove_inline_styles( \WP_REST_Response $response ): \WP_REST_Response {
		if ( isset( $response->data['content']['rendered'] ) ) {

			// remove attribute styles
			$response->data['content']['rendered'] = preg_replace('/(<[^>]+) style=".*?"/i', '$1', $response->data['content']['rendered'] );

			// remove inline style tags
			$response->data['content']['rendered'] = preg_replace('/<(?:style).*>.*<\/style>/si', '', $response->data['content']['rendered'] );
			
		}

		return $response;
	}
}

Atex::init();
